
% Compute Data
ne = zeros(50,12,2,100,3); % dim: voltage, RH, trail, time, SR
Te = zeros(50,12,2,100,3);
S = zeros(109,50,12,2,100,3);
index = 0;
for u = 1:50
    for rh = 1:12
        for T = 1:2
            index = index+1;
            disp(index/(50*12*2));
            [MStemp,SS] = ...
                RTPCD_MS_LeakyReLU_E_Reducedhv_KS01122021_Test(OEStestne(:,u,rh,T),...
                MSet.W1(:,:,1),MSet.W2(:,:,1),MSet.W3(:,:,1),MSet.W4(:,:,1),...
                MSet.W5(:,:,1),MSet.W6(:,:,1),MSet.W7(:,:,1),MSet.W8(:,:,1),...
                MSet.W9(:,:,1),MSet.W10(:,:,1),MSet.W11(:,:,1));
            ne(u,rh,T,:,:) = MStemp.Shist(1,:,1,:); % Shist dim: SS, time, MN, SR
            Te(u,rh,T,:,:) = MStemp.TeList(:,1,:); % TeList dim: time, MN, SR
            S(:,u,rh,T,:,:) = MStemp.Shist(:,:,1,:); % Shist dim: SS, time, MN, SR
        end
    end
end

% Plot ne and Te
figure();
RHlistexp = [35;40;45;45;45;50;55;60;65;70;75;80];
xi = (1:0.01:12)';
x = (1:1:12)';
RHfit = interp1q(x,RHlistexp,xi);
py = zeros(50,size(xi,1));
order = 1;
% ne dim: U, RH, T1/T2, time, SR
for SR = 1:3
    subplot(3,2,SR*2-1);
    hold on;
    for u = 1:50
        for T = 1:2
            neforplot = squeeze(max(ne(u,:,T,:,SR),[],4));
            scatter(RHlistexp,neforplot,50,[1-u/50,0,u/50]);
            % Trend Lines
            pcoeff = polyfit(RHlistexp, neforplot',order);
            py(u,:) = polyval(pcoeff,RHfit);
            plot(RHfit,py(u,:),'color',[1-u/50,0,u/50],'linewidth',1);
            title(strcat('Electron Density Region ',num2str(SR)));
        end
    end
    hold off;
    set(gca,'YScale','log');
    xlabel('Relative Humidity');
    ylabel('Electron Density [cm^-^3]');
    grid on;
end
% TeList dim: U, RH, T1/T2, time, SR
for SR = 1:3
    subplot(3,2,SR*2);
    hold on;
    for u = 1:50
        for T = 1:2
            Tem = findTemean(squeeze(Te(u,:,T,:,SR)));
            scatter(RHlistexp,Tem,50,[1-u/50,0,u/50]);
            % Trend Lines
            pcoeff = polyfit(RHlistexp, Tem,order);
            py(u,:) = polyval(pcoeff,RHfit);
            plot(RHfit,py(u,:),'color',[1-u/50,0,u/50],'linewidth',1);
            title(strcat('Mean Electron Temperature Region',num2str(SR)));
        end
    end
    hold off;
    xlabel('Relative Humidity');
    ylabel('Electron Temperature [eV]');
    grid on;
end

% Plot He-Air Ratio of SR
% He: 3, N2: 32, O2: 44, H2O+: 50, H2O: 52
% H: 23-26, H2O & OH: 50-56
% HNO: 65, 69-72
% S dim: SS, U, RH, T1/T2, time, SR
Hehist = zeros(50,12,2,3);
N2hist = zeros(50,12,2,3);
O2hist = zeros(50,12,2,3);
H2Ohist = zeros(50,12,2,3);
for SR = 1:3
    for u = 1:50
        for T = 1:2
            Hehist(u,:,T,SR) = mean(S(3,u,:,T,:,SR),5); 
            N2hist(u,:,T,SR) = mean(S(32,u,:,T,:,SR),5); 
            O2hist(u,:,T,SR) = mean(S(44,u,:,T,:,SR),5); 
            H2Ohist(u,:,T,SR) = mean(S(23,u,:,T,:,SR),5)+...
                mean(S(24,u,:,T,:,SR),5)+mean(S(25,u,:,T,:,SR),5)+...
                mean(S(26,u,:,T,:,SR),5)+mean(S(50,u,:,T,:,SR),5)+...
                mean(S(51,u,:,T,:,SR),5)+mean(S(52,u,:,T,:,SR),5)+...
                mean(S(53,u,:,T,:,SR),5)+mean(S(54,u,:,T,:,SR),5)+...
                mean(S(55,u,:,T,:,SR),5)+mean(S(56,u,:,T,:,SR),5)+...
                mean(S(65,u,:,T,:,SR),5)+mean(S(69,u,:,T,:,SR),5)+...
                mean(S(70,u,:,T,:,SR),5)+mean(S(71,u,:,T,:,SR),5)+...
                mean(S(72,u,:,T,:,SR),5);
        end
    end
end
HeAirR = Hehist./(N2hist+O2hist+H2Ohist);
H2OR = H2Ohist./(Hehist+N2hist+O2hist);
HeAirRm = zeros(10,12,2,3);
for i = 1:10
    HeAirRm(i,:,:,:) = mean(HeAirR((i-1)*5+1:(i-1)*5+5,:,:,:),1);
end

figure();
for SR = 1:3
    subplot(1,3,SR)
    imagesc((HeAirRm(:,:,1,SR)+HeAirRm(:,:,2,SR))/2);colormap('jet');colorbar;
end

HeAirRtot = squeeze(mean(mean(mean(HeAirR,1),2),3));
ca = categorical({'Region 1','Region 2','Region 3'});
figure();
bar(ca,HeAirRtot,'k');
ylabel('He-Air Ratio');
grid on;

function Tem = findTemean(Te)
Tem = squeeze(0.7*max(Te,[],2));
end

